@@ -2,13 +2,12 @@
 
 import click
 import MetaTrader5 as mt5
-from mtcli.conecta import conectar, shutdown
+from mtcli.conecta import shutdown
 from mtcli.logger import setup_logger
 
-from . import conf
 from .ordem import criar_ordem, enviar_ordem, inicializar
 
-log = setup_logger("trade")
+log = setup_logger()
 
 
 @click.command()
@@ -28,8 +27,6 @@ log = setup_logger("trade")
 @click.option("--preco", "-pr", type=float, default=None, help="Preço da ordem limit")
 def buy(symbol, lot, sl, tp, limit, preco):
     """Compra a mercado ou pendente com SL e TP."""
-    conectar()
-
     tick = inicializar(symbol)
     if not tick:
         return
