@@ -1,3 +1,5 @@
+"""Comando para exibir todas as posições."""
+
 import click
 import MetaTrader5 as mt5
 from mtcli.conecta import conectar, shutdown
@@ -5,7 +7,7 @@ from mtcli.logger import setup_logger
 
 from . import conf
 
-logger = setup_logger("trade")
+log = setup_logger()
 
 
 @click.command()
@@ -23,7 +25,7 @@ def pos(symbol):
             else "Nenhuma posição aberta encontrada."
         )
         click.echo(f"{msg}")
-        logger.info(f"{msg}")
+        log.info(f"{msg}")
         shutdown()
         return
 
@@ -31,9 +33,9 @@ def pos(symbol):
     for p in posicoes:
         tipo = "COMPRA" if p.type == mt5.POSITION_TYPE_BUY else "VENDA"
         click.echo(
-            f"{tipo} | {p.symbol} | volume: {p.volume:.2f} | preço: {p.price_open:.{conf.digitos}f} | lucro: {p.profit:.2f}"
+            f"{tipo} {p.symbol} {p.volume:.2f} {p.price_open:.{conf.digitos}f} lucro {p.profit:.2f}"
         )
-        logger.info(
+        log.info(
             f"{tipo} | {p.symbol} | volume: {p.volume:.2f} | preço: {p.price_open:.{conf.digitos}f} | lucro: {p.profit:.2f}."
         )
 
