@@ -2,13 +2,12 @@
 
 import click
 import MetaTrader5 as mt5
-from mtcli.conecta import conectar, shutdown
+from mtcli.conecta import shutdown
 from mtcli.logger import setup_logger
 
-from . import conf
 from .ordem import inicializar, criar_ordem, enviar_ordem
 
-log = setup_logger("trade")
+log = setup_logger()
 
 
 @click.command()
@@ -29,8 +28,6 @@ log = setup_logger("trade")
 @click.option("--preco", "-pr", type=float, default=None, help="Preço da ordem limit")
 def sell(symbol, lot, sl, tp, limit, preco):
     """Venda a mercado ou pendente com sl e tp."""
-    conectar()
-
     tick = inicializar(symbol)
     if not tick:
         return
